%	bin_mtu		MATLAB function
%
%	bin_tshl reads the binary  data from the selected files
%	skips samples according to vector skip to align data
%	properly and returns on array data of size (channels
% 	x nsamp) to plot.
%
%	USAGE: function [data]= bin_mtu(head,skip,nsec,k);
%
function [data,skip]= bin_mtu(head,skip,nsec,k);
global fid_bin naxes sc_factor format ext
global l3ns l4ns hsmp

% additional subsampling (every dbud's second)
dsub=10;

% initialize data array;
% read only first data of each record in case of nsec/head(k).dt > 5000
if ((char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4' | char(ext(k,1:3)) == 'ts5') & nsec/head(k).dt > 5000) 
    data =zeros(5,nsec/dsub);   
else
    data =zeros(5,round(nsec/head(k).dt));   
end

%   determine tag length (16 or 32)
fseek(fid_bin(k),0,-1);
tag = fread(fid_bin(k),16,'uint8');
tsize = tag(14); if (tsize == 0) tsize = 16; end;

if (char(ext(k,1:3)) == 'tsh')
     starttime = find_time_string(head,skip,0);
     if (head(k).dt <= 1/1000) % > 1000 Hz
         while (~(str2num(starttime(13:14)) == 0 & ...
                  mod(str2num(starttime(10:11)),hsmp(k)*2) == 1))
            skip = skip + 1;
            starttime = find_time_string(head,skip,0)
         end
      elseif (head(k).dt > 1/1000) % < 1000 Hz
         while (~(str2num(starttime(13:14)) == 0 & ...
                mod(str2num(starttime(10:11)),hsmp(k)*2) == 0))
            skip = skip + 1;
            starttime = find_time_string(head,skip,0);
         end
      end
      
      if (1/head(k).dt == 300 | 1/head(k).dt == 2400)
         usec_1 = 300; usec_2 = 2400;
      elseif(1/head(k).dt == 320 | 1/head(k).dt == 2560) 
         usec_1 = 320; usec_2 = 2560;
      elseif (1/head(k).dt == 384 | 1/head(k).dt == 3072) 
         usec_1 = 384; usec_2 = 3072;
      end
      
      % skip blocks of 3 and 4 recording pairs
      skip_tsh = floor(skip(k)/(2*60*hsmp(k))) * ...
         			(l4ns(k)*(3*head(k).nch*usec_1 + tsize) + ...
         		     l3ns(k)*(3*head(k).nch*usec_2 + tsize));
                 
      % skip remaining 3 or 4 recording block
      if (mod(skip(k),(2*60*hsmp(k))) >= 60*hsmp(k))
         if (head(k).dt <= 1/1000)    % > 1000 Hz
            skip_tsh = skip_tsh + l4ns(k)*(3*head(k).nch*usec_1 + tsize);
         elseif (head(k).dt > 1/1000) % < 1000 Hz
            skip_tsh = skip_tsh + l3ns(k)*(3*head(k).nch*usec_2 + tsize);
         end
      end
      
      % skip additional seconds due to system start within l3/4ns seconds
      if (mod(skip(k),60) > 0 & mod(skip(k),2*60*hsmp(k)) < 60*hsmp(k)) % system started during other band
          if (head(k).dt <= 1/1000)     % > 1000 Hz
              skip_tsh = skip_tsh + (l4ns(k)-(60-mod(skip(k),60)))*(3*head(k).nch*usec_1 + tsize);
          elseif (head(k).dt > 1/1000) % < 1000 Hz
              skip_tsh = skip_tsh + (l3ns(k)-(60-mod(skip(k),60)))*(3*head(k).nch*usec_2 + tsize);
          end
      elseif (mod(skip(k),60) > 0 & mod(skip(k),2*60*hsmp(k)) > 60*hsmp(k)) % system started during this band
          if (head(k).dt <= 1/1000)    % > 1000 Hz
              skip_tsh = skip_tsh + (l3ns(k)-(60-mod(skip(k),60)))*(3*head(k).nch*usec_2 + tsize);
          elseif (head(k).dt > 1/1000) % < 1000 Hz
              skip_tsh = skip_tsh + (l4ns(k)-(60-mod(skip(k),60)))*(3*head(k).nch*usec_1 + tsize);
          end
      end
            
  	  fseek(fid_bin(k),round(skip_tsh),-1);
      
      usec = 1/head(k).dt;
      for irec = 1:nsec        
         dummy = fread(fid_bin(k),tsize,'char');
         data(find(sc_factor(k,:)),1+(irec-1)*usec:irec*usec) = ...
              fread(fid_bin(k),[head(k).nch,usec],'bit24');
      end
elseif (char(ext(k,1:3)) == 'ts2' | char(ext(k,1:3)) == 'ts3')
      usec = round(1/head(k).dt);
      recskip = floor(skip(k)/(2*hsmp(k)*60));
      fseek(fid_bin(k),round(recskip*(3*head(k).nch*usec + tsize)),-1);
      for irec = 1:nsec        
      	dummy = fread(fid_bin(k),tsize,'char');
      	[data(find(sc_factor(k,:)),1+(irec-1)*usec:irec*usec),count] = ...
            fread(fid_bin(k),[head(k).nch,usec],'bit24');
   	  end
else    % this will have to be changed when ts4 data are non-contiguous
      usec = 1/head(k).dt;
      if (nsec/head(k).dt > 5000) usec=1; end
      if (nsec/head(k).dt > 5000) dsec=dsub; else dsec=1; end
      % for irec = 1:nsec        
      for isec = 1:nsec/dsec
        irec = isec*dsec; % e.g.: 1,2,3,4 for dsec=1 or 10,20,30 for dsec=10
        fseek(fid_bin(k),round((skip(k)+irec)*(3*head(k).nch/head(k).dt + tsize)),-1);
     	dummy = fread(fid_bin(k),tsize,'char');
      	[data(find(sc_factor(k,:)),1+(isec-1)*usec:isec*usec),count] = ...
            fread(fid_bin(k),[head(k).nch,usec],'bit24');
      end
end

% reorder in case of nch >= 4
ch_order = [3,4,5,1,2]; 
if (head(k).nch >= 4) data=data(ch_order,:); end;

return
