%	head_asc.m		MATLAB function
%
%   replaces load_asc.m
%
%   reads 
%   - header lines from asc file (if there is a header), and 
%   - conversion info (sc_factor) from sp file (if present) 

function [header] = head_asc(cfile,k)

global fid_asc sc_factor %fid_bin
%--------------------------------------------------------
%  	open the data file 
fid_asc(k) = fopen(char(cfile(k)),'r');
if fid_asc(k) < 0
    Warning=['Cannot open ',name,'; will not load MT data']
    return
end
% skip all header lines except the last three, which should loo like:
%#    0.12500            <== Data sample interval (seconds)
%#  2004  8  8  0  4 17  <= 1st data scan (y m d h m s) => nscans:     7637112
%#  2004  7  1  0  0  0  <= global clock zero (y m d h m s)
ihead=0;
while 1
    ihead = ihead+1;
    line = fgetl(fid_asc(k));
    kline{ihead} = line;
    if (line(1:1) ~= '#')   
        % probe for number of channels
        nch = length(str2num(line))
        break; 
    end
end
% 3 header lines found?
if  ihead>=4
    delta = sscanf(char(kline{ihead-3}),'%*s %f',1)
    if ~isnumeric(delta) 
        delta=1 
    end
    line=char(kline{ihead-2});
    [start,count,errmsg,nindex] = sscanf(line,'%*s %d %d %d %d %d %d',6);
    start
    if ~(isnumeric(start) & length(start)==6 & ...
         (start(2)>=1 & start(2)<=12) & (start(3)>=1 & start(3)<=31))
        Warning=['No start time found - assume:']
        start = [2004,01,01,00,00,00]
    end
    nscans = sscanf(line(nindex:length(line)),...
            '%*s %*s %*s %*s %*s %*s %*s %*s %*s %*s %*s %*s %d',1)
    if ~isnumeric(nscans)
        Warning=['Number of scans not found! - assume 10^7']
        nscans=10^7
    end
    line=char(kline{ihead-1});
    tglobal = sscanf(line,'%*s %d %d %d %d %d %d',6)
end
%--------------------------------------------------------

%------------------------------------------------------
% calculate stop time (taken from find_time_string.m, 
% head_nims would have been another choice)
months = [31 28 31 30 31 30 31 31 30 31 30 31];
secs = floor(nscans*delta);

nd = floor(secs/(24*(60*60)));			rest = mod(secs,24*(60*60));
nh = floor(rest/(60*60));		        rest = mod(rest,(60*60));
nm = floor(rest/60);					rest = mod(rest,60);
ns = rest;

second 	= mod(ns+start(6),60);      note = floor((ns+start(6))/60);
minute	= mod(nm+start(5)+note,60); note = floor((nm+start(5)+note)/60);
hour   	= mod(nh+start(4)+note,24); note = floor((nh+start(4)+note)/24);
day		= nd+start(3)+note;
month  	= start(2);
year   	= start(1);

kmon = 0;
while day > months(month)
   day   = day - months(month);
   kmon  = kmon+1;
   month = mod(start(2) + kmon,12); if (month == 0) month = 12; end
   if start(2) + kmon > 12
      year = year + 1;
   end
end
stop = [year, month, day, hour, minute, second]' 
%------------------------------------------------------

%------------------------------------------------------
% check for sp file for conversions
cdot = findstr(cfile{k},'.');
spfile = [cfile{k}(1:cdot),'sp']
fid = fopen(spfile,'r');
if fid < 0
    Warning=['Cannot open Sp file ',spfile]
    disp('=> Use default conversions')
    % set defaults (Nims); Mag: nT / Tel: mV/km w/ lines=100m
    %sc_factor(k,1:3) = [.01 0.01 0.01];
    %efact = 2.441406e-6 * 1000 / 100;
    %sc_factor(k,4:5) = [efact, efact];
    sc_factor(k,1:5) = [1 1 1 1 1];
else
    % read sp file
    isp=0; icmp=0; cmpline=0; tel=1; gain=1; done = [0 0 0 0 0];
    while 1
        isp = isp+1;
        line = fgetl(fid);
        if isp==4 nch=sscanf(line,'%d',1); end
        if (line(1:1)=='H' | line(1:1)=='B' | line(1:1)=='E') & ...
           (line(2:2)=='x' | line(2:2)=='y' | line(2:2)=='z')
            icmp = icmp+1;
            if line(1:1)=='E'
                isE=1; cmpline = isp+1;
            else 
                isE=0; cmpline = isp+2;
            end
        end
        if (isp==cmpline & isE==1)
            [tmp] = sscanf(line,'%f %*s %*s %f',2);
            tel =tmp(1)
            gain=tmp(2)
            cmpline = isp+1; isE=0;
        elseif (isp==cmpline & isE==0)
            fact = sscanf(line,'%f',1);
            sc_factor(k,icmp) = fact/(tel*gain);
            tel=1; gain=1; done(icmp)=1;
        end
        if done(nch) break; end    
    end
    fclose(fid);
end
%-------------------------------------------------
    
header = struct('start_year',start(1),'start_mon',start(2),'start_day',start(3),...
                'start_hr',start(4),'start_min',start(5),'start_sec',start(6),...
                'stop_year',stop(1),'stop_mon',stop(2),'stop_day',stop(3),...
                'stop_hr',stop(4),'stop_min',stop(5),'stop_sec',stop(6),...
                'dt',delta,'nch',nch);  %  put into structure
return
