%	head_nims   MATLAB function 
% 	
%	reads information from the LIMS data files header: 
%   Start time, sampling rate and # of channels. 
%   Returns header structure 
%   containing start time, # of channels and sampling rate.
%
%	USAGE: [header] = head_lims(cfile,k)
%

function [header] = head_nims(cfile,k)

    global fid_bin sc_factor
 
    gain=200;
    Ecount=8.192*1e3/(256*256*256)/gain;
  
    %  	open the data file 
    fid_bin(k) = fopen(char(cfile(k)),'r','ieee-le');
    if fid_bin(k) < 0
      Warning=['Cannot open ',name,'; will not load MT data']
    end
    %   make sure position is right at the beginning
    fseek(fid_bin(k),0,-1);
    
    % read values in the data header
    dummy=fread(fid_bin(k),1,'int32');
    lat=fread(fid_bin(k),1,'single')
    lon=fread(fid_bin(k),1,'single')
    decl=fread(fid_bin(k),1,'single')
    delta=fread(fid_bin(k),1,'single')
    start=fread(fid_bin(k),6,'int32')
    tglobal=fread(fid_bin(k),6,'int32')
    % nscans: number of scans, not seconds
    nscans=fread(fid_bin(k),1,'int32')
    % skip over eor characters
    idummy=fread(fid_bin(k),2,'int32');

    % calculate stop time of acquisition 
    % start time & nscans
    nsecs = nscans*delta;
    add_hh = 0; add_dd = 0;
    add_mm = 0; add_yy = 0;
    mon_days = [31,28,31,30,31,30,31,31,30,31,30,31];

    % duration in seconds, minutes, hours
    ndur = nsecs;
    moduli = [60,60,24,1000];
    for imod = 1:4
        dur(imod) = mod(ndur,moduli(imod));
        ndur = floor(ndur/moduli(imod));
    end
    
    stop(6) = start(6)+dur(1); % second
    if  stop(6) >= 60  
        stop(6) = stop(6)-60; add_mm = 1;
    end
    stop(5) = start(5)+dur(2)+add_mm; % minute
    if  stop(5) >= 60  
        stop(5) = stop(5)-60; add_hh = 1;
    end
    stop(4) = start(4)+dur(3)+add_hh; % hour
    if  stop(4) >= 24
        stop(4) = stop(4)-24; add_dd = 1;
    end
    add_mm=0;
    stop(3) = start(3)+dur(4)+add_dd; % day
    while stop(3) > mon_days(start(2)+add_mm) 
        stop(3) = stop(3)-mon_days(start(2)+add_mm);
        add_mm = add_mm+1;
    end
    stop(2) = start(2)+add_mm; % month
    if  stop(2)>12; add_yy = 1; end
    stop(1) = start(1)+add_yy; % year
    
    %-------------------------------------------------
    % telluric lengths in hdr file
    charfile = char(cfile(k));
    ll = findstr(charfile,'.');
    if (charfile(ll-1:ll-1) == 'C')
            ll = ll-1;
    end
    cfile_hdr = [charfile(1:ll-1),'.hdr'];
    fid_hdr = fopen(cfile_hdr,'r');
    if fid_hdr < 0
        Warning=['Cannot open hdr file -> 100 m E-line lengths assumed']
        elength = [100,100];
    else
        ctemp = fgets(fid_hdr);
        while (isempty(findstr((ctemp),'WIRE LENGTH')))
        ctemp = fgets(fid_hdr);
        end
        elength(1) = str2num(ctemp(3:7));
        ctemp = fgets(fid_hdr);
        elength(2) = str2num(ctemp(3:7));
        if (elength(1)<5 | elength(1)>5000) 
           Warning=['E-lines not found in hdr file -> 100 m assumed']
           elength = [100,100];
        end
        fclose(fid_hdr);
    end
    %-------------------------------------------------
    
    header = struct('start_year',start(1),'start_mon',start(2),'start_day',start(3),...
                    'start_hr',start(4),'start_min',start(5),'start_sec',start(6),...
                    'stop_year',stop(1),'stop_mon',stop(2),'stop_day',stop(3),...
                    'stop_hr',stop(4),'stop_min',stop(5),'stop_sec',stop(6),...
                    'dt',delta,'nch',5);  %  put into structure
                 
    %hx=data(:,1)/100;
    %hy=data(:,2)/100;
    %hz=data(:,3)/100;
    %ex=data(:,4)*Ecount;
    %ey=data(:,5)*Ecount;

    for ichan = 1:5
       	sc_factor(k,ichan) = 0;
       	if ichan <= 3
         	sc_factor(k,ichan) = 1/100;
        elseif ichan >= 4
            sc_factor(k,ichan) = (-1)*Ecount*(1000/elength(ichan-3));
        end
    end
    
 return
  
