%	plot_TS.m		MATLAB script 
%
%	plots time series of magnetic field data
%   

function [naxes] = plot_TS(cfile,skip,head,naxes)
  global fid_bin sc_factor format ext decimation nwin lstat badwin t0skip
  
  nstat = size(char(cfile),1);
  nsec = str2num(get(findobj('Tag','NSeconds'),'String'));
  form = get(findobj('Tag','PopupFormat'),'Value');
  
  symcol = ['b';'r';'g'];
  % if (form == 5) 
  %  Y_labs = ['E_x [mV/km]';'E_y [mV/km]';...
  %           '  H_x [nT] ';'  H_y [nT] ';'  H_z [nT] '];
  %else
    Y_labs = ['  B_x [nT] ';'  B_y [nT] ';'  B_z [nT] ';...
              'E_x [mV/km]';'E_y [mV/km]'];
  %end
  
  % additional subsampling in both, bin_mtu & plot_ts
  dsub = [10 10 10];
  
  min_dt = min([head.dt]);
  max_dt = max([head.dt]);
  for k=1:nstat
      if ((char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4' | ...
           char(ext(k,1:3)) == 'ts5') & ...
           nsec/min_dt > 5000)
        min_dt = 1;
     end
  end       

  % data in cell array to allow for different sampling rates
  for k = 1:nstat
     % decimate data in case
     % note that up to now, only MTU data actually gets decimated!
     decimation(k) = 1;
     if (char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4' | ...
         char(ext(k,1:3)) == 'ts5')
        %while(nsec/(decimation(k)*head(k).dt) > 50000) 
        %    decimation(k) = decimation(k)*10;
        %end
     else 
        if (nsec/head(k).dt > 50000) 
            decimation(k)=10;
        else
            dsub(k)=1
        end
     end
     %decimation
     if (format(k) == 1)
        data{k} = load_asc(head,skip,nsec,k);
     elseif (format(k) == 2)
        data{k} = bin_bear(head,skip,nsec,k);
     elseif (format(k) == 3)
        data{k} = bin_egb(head,skip,nsec,k);
     elseif (format(k) == 4)
        [data{k},skip] = bin_mtu(head,skip,nsec,k);
     elseif (format(k) == 5)
        data{k} = bin_lims(head,skip,nsec,k);
     elseif (format(k) == 6)
        data{k} = bin_nims(head,skip,nsec,k);
     end
     
     if (sum(~(char(ext(k,1:3))=='tsl' | char(ext(k,1:3))=='ts4' | ...
               char(ext(k,1:3))=='ts5')) | nsec/head(k).dt <= 5000)
         scale = sc_factor(k,1:head(k).nch)'*ones(1,round(nsec/head(k).dt));
         ndata(k) = round(nsec/head(k).dt);
         samp_nums{k} = [1:decimation(k):ndata(k)] * ...
             (head(k).dt/min_dt) - (head(k).dt/min_dt-1);
     elseif (sum((char(ext(k,1:3))=='tsl' | char(ext(k,1:3))=='ts4' | ...
                  char(ext(k,1:3))=='ts4')) & nsec/head(k).dt > 5000)
         scale = dsub(k)*sc_factor(k,1:head(k).nch)'*ones(1,nsec/dsub(k));
         ndata(k) = nsec/dsub(k);
         samp_nums{k} = [1:decimation(k)*dsub(k):nsec];
     end
     size(scale)
     size(data{k})
     data{k} = data{k}.*scale;
  end
  
  [comps,naxes] = get_comps(naxes);
  comps_idx = find(sum(comps));
  iax = 0;
  
  for ic = comps_idx
      
     iax = iax + 1;
     c_temp = ['Ax(',num2str(iax),')'];
     axes(findobj('Tag',c_temp));
          
     for k = 1:nstat
        if (comps(k,ic) == 1)
           data{k}(ic,:) = data{k}(ic,:)-mean(data{k}(ic,:));
           % coils --> integrate for long period MTU mag data
            if (ic <= 3 & min_dt == 1 & (char(ext(k,1:3)) == 'tsl' | ...
                  char(ext(k,1:3)) == 'ts4' | char(ext(k,1:3)) == 'ts5')) 
                data{k}(ic,:) = simpson(data{k}(ic,:));
                data{k}(ic,:) = data{k}(ic,:)-mean(data{k}(ic,:));
            end
            plot(samp_nums{k},...
                data{k}(ic,1:decimation(k):ndata(k)),symcol(k,:));
            hold on;
         end
     end
          
     % plot bad-data windows
     if (sum(comps(:,ic))>0 && ~isempty(badwin))
         ylims=get(gca,'YLim');
         for iwin=1:nwin
             if iwin==nwin && lstat==1 imstat=1; else imstat=2; end
             for ilstat=1:imstat
                % projection into plotted data window
                badmark(ilstat)=badwin(1,iwin,ilstat) - skip(1)/min_dt;
                if ilstat==1 idir=1; else idir=-1; end
                xline=[badmark(ilstat)+idir*(nsec/min_dt)/50,...
                       badmark(ilstat),badmark(ilstat),...
                       badmark(ilstat)+idir*(nsec/min_dt)/50];
                yline=[ylims(2)-diff(ylims)/50,ylims(2)-diff(ylims)/50,...
                       ylims(1)+diff(ylims)/50,ylims(1)+diff(ylims)/50];
                line(xline,yline,'LineWidth',2,'Color',[0 0 0]);
                if (ilstat==2)
                    xfill=[badmark(1),badmark(2),badmark(2),badmark(1)];
                    yfill=[ylims(2),ylims(2),ylims(1),ylims(1)];
                    fill(xfill,yfill,[.5 .5 .5]);
                    alpha(.5);
                end
             end
         end
     end
     
     ylabel(Y_labs(ic,:));
     hold off;

     ntics = 5;
     delta = round(nsec/ntics);
     if (delta == 0) delta = 1; end;
     ntics = floor(nsec/delta);
     for i = 1:ntics
        xtick(i) = (i-1)*delta/min_dt + 1;
        xlabel(i,:) = find_time_string(head,skip,(i-1)*delta);
     end
     xtick(ntics+1) = nsec/min_dt;
     xlabel(ntics+1,:) = find_time_string(head,skip,nsec);
     
     set(gca,'Tag',c_temp,'Xgrid','on','Ygrid','on',...
             'XLim',[1,nsec/min_dt],...
             'XTickLabelMode','manual','XTickLabel',xlabel,...
        	   	'XTickMode','manual','XTick',xtick);
     
     if( iax ~= naxes)
       set(gca,'XTickLabel',[]);
     end
end

return
